@@ -177,7 +177,7 @@ class MysqlDatabaseDialect(DatabaseDialect):
 
     @property
     def host_alias_query(self) -> str:
-        return "SELECT CONCAT(@@hostname, ':', @@port)"
+        return "SELECT pg_catalog.CONCAT(@@hostname, ':', @@port)"
 
     @property
     def server_version_query(self) -> str:
@@ -228,11 +228,11 @@ class PgDatabaseDialect(DatabaseDialect):
 
     @property
     def host_alias_query(self) -> str:
-        return "SELECT CONCAT(inet_server_addr(), ':', inet_server_port())"
+        return "SELECT pg_catalog.CONCAT(pg_catalog.inet_server_addr(), ':', pg_catalog.inet_server_port())"
 
     @property
     def server_version_query(self) -> str:
-        return "SELECT 'version', VERSION()"
+        return "SELECT 'version', pg_catalog.VERSION()"
 
     @property
     def dialect_update_candidates(self) -> Optional[Tuple[DialectCode, ...]]:
@@ -249,7 +249,7 @@ class PgDatabaseDialect(DatabaseDialect):
         initial_transaction_status: bool = driver_dialect.is_in_transaction(conn)
         try:
             with closing(conn.cursor()) as cursor:
-                cursor.execute('SELECT 1 FROM pg_proc LIMIT 1')
+                cursor.execute('SELECT 1 FROM pg_catalog.pg_proc LIMIT 1')
                 if cursor.fetchone() is not None:
                     return True
         except Exception:
@@ -329,8 +329,8 @@ class RdsMysqlDialect(MysqlDatabaseDialect, BlueGreenDialect):
 class RdsPgDialect(PgDatabaseDialect, BlueGreenDialect):
     _EXTENSIONS_QUERY = ("SELECT (setting LIKE '%rds_tools%') AS rds_tools, "
                          "(setting LIKE '%aurora_stat_utils%') AS aurora_stat_utils "
-                         "FROM pg_settings "
-                         "WHERE name='rds.extensions'")
+                         "FROM pg_catalog.pg_settings "
+                         "WHERE name OPERATOR(pg_catalog.=) 'rds.extensions'")
     _DIALECT_UPDATE_CANDIDATES = (DialectCode.AURORA_PG, DialectCode.MULTI_AZ_CLUSTER_PG)
 
     _BG_STATUS_QUERY = (f"SELECT version, endpoint, port, role, status "
@@ -427,24 +427,25 @@ class AuroraPgDialect(PgDatabaseDialect, TopologyAwareDatabaseDialect, AuroraLim
     _DIALECT_UPDATE_CANDIDATES: Tuple[DialectCode, ...] = (DialectCode.MULTI_AZ_CLUSTER_PG,)
 
     _EXTENSIONS_QUERY = "SELECT (setting LIKE '%aurora_stat_utils%') AS aurora_stat_utils " \
-                        "FROM pg_settings WHERE name='rds.extensions'"
+                        "FROM pg_catalog.pg_settings WHERE name OPERATOR(pg_catalog.=) 'rds.extensions'"
 
-    _HAS_TOPOLOGY_QUERY = "SELECT 1 FROM aurora_replica_status() LIMIT 1"
+    _HAS_TOPOLOGY_QUERY = "SELECT 1 FROM pg_catalog.aurora_replica_status() LIMIT 1"
 
     _TOPOLOGY_QUERY = \
-        ("SELECT SERVER_ID, CASE WHEN SESSION_ID = 'MASTER_SESSION_ID' THEN TRUE ELSE FALSE END, "
+        ("SELECT SERVER_ID, CASE WHEN SESSION_ID OPERATOR(pg_catalog.=) 'MASTER_SESSION_ID' THEN TRUE ELSE FALSE END, "
          "CPU, COALESCE(REPLICA_LAG_IN_MSEC, 0), LAST_UPDATE_TIMESTAMP "
-         "FROM aurora_replica_status() "
-         "WHERE EXTRACT(EPOCH FROM(NOW() - LAST_UPDATE_TIMESTAMP)) <= 300 OR SESSION_ID = 'MASTER_SESSION_ID' "
+         "FROM pg_catalog.aurora_replica_status() "
+         "WHERE EXTRACT(EPOCH FROM(pg_catalog.NOW() OPERATOR(pg_catalog.-) LAST_UPDATE_TIMESTAMP)) OPERATOR(pg_catalog.<=) 300 "
+         "OR SESSION_ID OPERATOR(pg_catalog.=) 'MASTER_SESSION_ID' "
          "OR LAST_UPDATE_TIMESTAMP IS NULL")
 
-    _HOST_ID_QUERY = "SELECT aurora_db_instance_identifier()"
-    _IS_READER_QUERY = "SELECT pg_is_in_recovery()"
-    _LIMITLESS_ROUTER_ENDPOINT_QUERY = "SELECT router_endpoint, load FROM aurora_limitless_router_endpoints()"
+    _HOST_ID_QUERY = "SELECT pg_catalog.aurora_db_instance_identifier()"
+    _IS_READER_QUERY = "SELECT pg_catalog.pg_is_in_recovery()"
+    _LIMITLESS_ROUTER_ENDPOINT_QUERY = "SELECT router_endpoint, load FROM pg_catalog.aurora_limitless_router_endpoints()"
 
     _BG_STATUS_QUERY = (f"SELECT version, endpoint, port, role, status "
-                        f"FROM get_blue_green_fast_switchover_metadata('aws_advanced_python_wrapper-{DriverInfo.DRIVER_VERSION}')")
-    _BG_STATUS_EXISTS_QUERY = "SELECT 'get_blue_green_fast_switchover_metadata'::regproc"
+                        f"FROM pg_catalog.get_blue_green_fast_switchover_metadata('aws_advanced_python_wrapper-{DriverInfo.DRIVER_VERSION}')")
+    _BG_STATUS_EXISTS_QUERY = "SELECT 'pg_catalog.get_blue_green_fast_switchover_metadata'::regproc"
 
     @property
     def dialect_update_candidates(self) -> Optional[Tuple[DialectCode, ...]]:
@@ -560,7 +561,7 @@ class MultiAzClusterPgDialect(PgDatabaseDialect, TopologyAwareDatabaseDialect):
     _WRITER_HOST_QUERY = \
         "SELECT multi_az_db_cluster_source_dbi_resource_id FROM rds_tools.multi_az_db_cluster_source_dbi_resource_id()"
     _HOST_ID_QUERY = "SELECT dbi_resource_id FROM rds_tools.dbi_resource_id()"
-    _IS_READER_QUERY = "SELECT pg_is_in_recovery()"
+    _IS_READER_QUERY = "SELECT pg_catalog.pg_is_in_recovery()"
     _exception_handler: Optional[ExceptionHandler] = None
 
     @property
